==> helpme-0.0.2.tar.gz: helpme-0.0.2/helpme/main/github/utils.py <==
'''

Copyright (C) 2017-2018 Vanessa Sochat.

This program is free software: you can redistribute it and/or modify it
under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

'''

from helpme.logger import bot
import sys
import requests
import json


def create_issue(title, body, repo, token):
    '''create a Github issue, given a title, body, repo, and token.

       Parameters
       ==========
       title: the issue title
       body: the issue body
       repo: the full name of the repo
       token: the user's personal Github token

    '''
    owner, name = repo.split('/')
    url = 'https://api.github.com/repos/%s/%s/import/issues' % (owner, name)
    
    data = {'issue': {'title': title, 'body': body }}

    headers = { "Authorization": "token %s" % token,
                "Accept": "application/vnd.github.golden-comet-preview+json" }

    response = requests.post(url, data=json.dumps(data), headers=headers)

    if response.status_code == 202:
        url = response.json()['url']
        bot.info('https://www.github.com/%s/issues' %repo)
        return url

    elif response.status_code == 404:
        bot.error('Cannot create issue. Does your token have scope repo?')
        sys.exit(1)

    else:
        bot.error('Cannot create issue %s' %title)
        bot.error(response.content)
        sys.exit(1)

==> helpme-0.0.35.tar.gz: helpme-0.0.35/helpme/main/github/utils.py <==
'''

Copyright (C) 2017-2018 Vanessa Sochat.

This program is free software: you can redistribute it and/or modify it
under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

'''

from helpme.logger import bot
import sys
import requests
import json


def create_issue(title, body, repo, token):
    '''create a Github issue, given a title, body, repo, and token.

       Parameters
       ==========
       title: the issue title
       body: the issue body
       repo: the full name of the repo
       token: the user's personal Github token

    '''
    owner, name = repo.split('/')
    url = 'https://api.github.com/repos/%s/%s/issues' % (owner, name)
    
    data = {'title': title, 'body': body }

    headers = { "Authorization": "token %s" % token,
                "Accept": "application/vnd.github.symmetra-preview+json" }

    response = requests.post(url, data=json.dumps(data), headers=headers)

    if response.status_code in [201, 202]:
        url = response.json()['html_url']
        bot.info(url)
        return url

    elif response.status_code == 404:
        bot.error('Cannot create issue. Does your token have scope repo?')
        sys.exit(1)

    else:
        bot.error('Cannot create issue %s' %title)
        bot.error(response.content)
        sys.exit(1)
